<!DOCTYPE html>
<!-- SPDX-License-Identifier: MIT -->
<!-- Copyright (c) 2025 Matthias Bilger matthias@bilger.info -->
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>About Mutenix</title>
    <link rel="stylesheet" href="/static/css/styles.css">
</head>
<body>
    <h1>About Mutenix</h1>
    <div id="readme-content">
        {{ readme_content|safe }}
    </div>
    <h2>License</h2>
    <div id="license-content">
        {{ license_content|safe }}
    </div>
</body>
</html>
